@@ -6,6 +6,6 @@ from google.protobuf import reflection as _reflection
 from google.protobuf import symbol_database as _symbol_database
 _sym_db = _symbol_database.Default()
 from .....tensorflow.core.protobuf import error_codes_pb2 as tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2
-from tensorflow.core.protobuf.error_codes_pb2 import *
+from .....tensorflow.core.protobuf.error_codes_pb2 import *
 DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/lib/core/error_codes.proto', package='', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/core/lib/core/error_codes.proto\x1a*tensorflow/core/protobuf/error_codes.protoP\x00b\x06proto3', dependencies=[tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2.DESCRIPTOR], public_dependencies=[tensorflow_dot_core_dot_protobuf_dot_error__codes__pb2.DESCRIPTOR])
 _sym_db.RegisterFileDescriptor(DESCRIPTOR)
